@@ -84,9 +84,12 @@ static void main_win_init(MainWin *self)
   GtkWidget *hbox;
   GtkAccelGroup *accel;
   GList *focus_chain;
+  const gint default_width = 240;
 
   GTK_WINDOW(self)->type = GTK_WINDOW_TOPLEVEL;
   gtk_window_set_title(GTK_WINDOW(self), _("Breeze"));
+  gtk_widget_set_size_request(GTK_WIDGET(self), default_width, -1);
+  gtk_window_set_resizable(GTK_WINDOW(self), FALSE);
   gtk_window_set_position(GTK_WINDOW(self), GTK_WIN_POS_CENTER);
   gtk_container_set_border_width(GTK_CONTAINER(self), 4);
   //gtk_window_set_decorated(GTK_WINDOW(self), FALSE);
@@ -125,8 +128,6 @@ static void main_win_init(MainWin *self)
   accel = gtk_accel_group_new();
   gtk_window_add_accel_group(GTK_WINDOW(self), accel);
   gtk_widget_add_accelerator(button, "clicked", accel, GDK_Escape, 0, 0);
-
-  gtk_widget_show_all(GTK_WIDGET(self));
 }
 
 GtkWidget *main_win_new(void)
@@ -229,8 +230,15 @@ static GtkTreeModel *create_completion_model(void)
   return GTK_TREE_MODEL(store);
 }
 
-int main_win_run(MainWin *win)
+gint main_win_run(MainWin *self)
 {
+  gtk_widget_show_all(GTK_WIDGET(self));
+
+  /* get focus, raise and be sticky */
+  gdk_window_set_keep_above(GTK_WIDGET(self)->window, TRUE);
+  gtk_window_stick(GTK_WINDOW(self));
+  gtk_window_present(GTK_WINDOW(self));
+
   gtk_main();
 
   return 0;
